# pio_beeper.py - 22.01.2022
#
# Ein einfacher Beeper für den Pi Pico in asm_pio / Micropython
# Für einen einzelnen Ton mit einstellbarer Dauer (in Millisekunden)
# Default-Dauer ist 1/4 Sekunde

from machine import Pin
from rp2 import PIO, StateMachine, asm_pio

# ----------------------------------------------------
@asm_pio(sideset_init=PIO.OUT_LOW)
def pio_beeper():
    
    wrap_target()
       
    pull()                         #  1 Dauer des Tons abholen
    out(x, 32)                     #  2 = Anzal der Xyxles
    
    label("next")
    nop()                .side(1)  #  3
    jmp(x_dec, "next")   .side(0)  #  4
       
    wrap()
    
# ---------------------------------------------------

class Beeper(object):
    def __init__(self, beep_pin, beep_freq=3500, statemachine=4):
        self.beep_freq = beep_freq
        self.sm = StateMachine(statemachine, pio_beeper, freq=beep_freq*2, sideset_base=Pin(beep_pin))
        self.sm.restart()
        self.sm.active(1)

    def beep(self, duration=250):
        # Negative Werte ergeben öange Beepzeiten,
        # zu kleine Werte sind nicht wahrnehmbar
        duration = 50 if duration < 50 else int(duration)
        self.sm.put((self.beep_freq * duration) // 1000)


if __name__ == "__main__":
    
    bp = Beeper(beep_pin = 0)
    bp.beep()
    
    print("done")






